@@ -3,6 +3,7 @@
 
 #include <stdexcept>
 #include <string>
+#include <configparser.h>
 
 #include <sqlite3.h>
 
@@ -26,6 +27,18 @@ class configexception : public std::exception {
 		std::string msg;
 };
 
+class confighandlerexception : public std::exception {
+	public:
+		confighandlerexception(const std::string& emsg) { msg = emsg; }
+		confighandlerexception(action_handler_status e);
+		virtual ~confighandlerexception() throw() { }
+		virtual const char * what() const throw() { return msg.c_str(); }
+		int status() { return 0; }
+	private:
+		const char * get_errmsg(action_handler_status e);
+		std::string msg;
+};
+
 class dbexception : public std::exception {
 	public:
 		dbexception(sqlite3 * h) : msg(sqlite3_errmsg(h)) { }
@@ -37,13 +50,14 @@ class dbexception : public std::exception {
 
 class matcherexception : public std::exception {
 	public:
-		enum errortype_t { ATTRIB_UNAVAIL };
-		matcherexception(errortype_t et, const std::string& info) : type(et), addinfo(info) { }
+		enum errortype_t { ATTRIB_UNAVAIL, INVALID_REGEX };
+		matcherexception(errortype_t et, const std::string& info, const std::string& info2 = "") : type(et), addinfo(info), addinfo2(info2) { }
 		virtual ~matcherexception() throw() { }
 		virtual const char * what() const throw();
 	private:
 		errortype_t type;
 		std::string addinfo;
+		std::string addinfo2;
 };
 
 }
