@@ -3,6 +3,7 @@
 
 #include <vector>
 #include <string>
+#include <stdexcept>
 
 #include <logger.h>
 #include <curl/curl.h>
@@ -11,6 +12,28 @@
 
 namespace newsbeuter {
 
+// wrapped curl handle for exception safety and so on
+// see also: https://github.com/gsauthof/ccurl
+class curl_handle {
+	private:
+		CURL *h;
+		curl_handle(const curl_handle &);
+		curl_handle &operator=(const curl_handle &);
+	public:
+		curl_handle()
+			: h(0)
+		{
+			h = curl_easy_init();
+			if (!h)
+				throw std::runtime_error("Can't obtain curl handle");
+		}
+		~curl_handle()
+		{
+			curl_easy_cleanup(h);
+		}
+		CURL *ptr() { return h; }
+};
+
 class utils {
 	public:
 		static std::vector<std::string> tokenize(const std::string& str, std::string delimiters = " \r\n\t");
@@ -27,7 +50,7 @@ class utils {
 
 		static std::string get_command_output(const std::string& cmd);
 		static void extract_filter(const std::string& line, std::string& filter, std::string& url);
-		static std::string retrieve_url(const std::string& url, configcontainer * cfgcont = NULL, const char * authinfo = NULL);
+		static std::string retrieve_url(const std::string& url, configcontainer * cfgcont = NULL, const char * authinfo = NULL, const std::string* postdata = NULL);
 		static void run_command(const std::string& cmd, const std::string& param); // used for notifications only
 		static std::string run_program(char * argv[], const std::string& input);
 
@@ -42,6 +65,7 @@ class utils {
 		static std::wstring utf8str2wstr(const std::string& utf8str);
 
 		static std::string to_s(unsigned int u);
+		static std::string signed_to_s(int u);
 
 		static std::string absolute_url(const std::string& url, const std::string& link);
 
@@ -81,7 +105,7 @@ class utils {
 		static void set_common_curl_options(CURL * handle, configcontainer * cfg);
 
 		static curl_proxytype get_proxy_type(const std::string& type);
-		static int get_auth_method(const std::string& type);
+		static unsigned long get_auth_method(const std::string& type);
 
 		static bool is_special_url(const std::string& url);
 
