@@ -84,6 +84,7 @@ configcontainer::configcontainer()
 	config_data["reload-threads"] = configdata("1", configdata::INT);
 	config_data["keep-articles-days"] = configdata("0", configdata::INT);
 	config_data["bookmark-interactive"] = configdata("false", configdata::BOOL);
+	config_data["bookmark-autopilot"] = configdata("false", configdata::BOOL);
 	config_data["mark-as-read-on-hover"] = configdata("false", configdata::BOOL);
 	config_data["search-highlight-colors"] = configdata("black yellow bold", configdata::STR, true);
 	config_data["pager"] = configdata("internal", configdata::PATH);
@@ -110,6 +111,9 @@ configcontainer::configcontainer()
 	config_data["ttrss-flag-star"] = configdata("", configdata::STR);
 	config_data["ttrss-flag-publish"] = configdata("", configdata::STR);
 	config_data["delete-read-articles-on-quit"] = configdata("false", configdata::BOOL);
+	config_data["openbrowser-and-mark-jumps-to-next-unread"] = configdata("false", configdata::BOOL);
+	config_data["toogleitemread-jumps-to-next-unread"] = configdata("false", configdata::BOOL);
+	config_data["markfeedread-jumps-to-next-unread"] = configdata("false", configdata::BOOL);
 
 	/* title formats: */
 	config_data["feedlist-title-format"] = configdata(_("%N %V - Your feeds (%u unread, %t total)%?T? - tag `%T'&?"), configdata::STR);
