@@ -30,6 +30,7 @@
 #include <ctime>
 #include <cassert>
 #include <signal.h>
+#include <unistd.h>
 #include <sys/utsname.h>
 #include <langinfo.h>
 #include <libgen.h>
@@ -157,8 +158,8 @@ void controller::setup_dirs(bool silent) {
 		if (spw) {
 			env_home = spw->pw_dir;
 		} else {
-			std::cout << _("Fatal error: couldn't determine home directory!") << std::endl;
-			std::cout << utils::strprintf(_("Please set the HOME environment variable or add a valid user for UID %u!"), ::getuid()) << std::endl;
+			std::cerr << _("Fatal error: couldn't determine home directory!") << std::endl;
+			std::cerr << utils::strprintf(_("Please set the HOME environment variable or add a valid user for UID %u!"), ::getuid()) << std::endl;
 			::exit(EXIT_FAILURE);
 		}
 	}
@@ -281,14 +282,20 @@ void controller::run(int argc, char * argv[]) {
 			case 'x':
 				execute_cmds = true;
 				break;
+			case 'q':
+				break;
 			case 'd': // this is an undocumented debug commandline option!
 				GetLogger().set_logfile(optarg);
 				break;
 			case 'l': // this is an undocumented debug commandline option!
 				{
 					loglevel level = static_cast<loglevel>(atoi(optarg));
-					if (level > LOG_NONE && level <= LOG_DEBUG)
+					if (level > LOG_NONE && level <= LOG_DEBUG) {
 						GetLogger().set_loglevel(level);
+					} else {
+						std::cerr << utils::strprintf(_("%s: %d: invalid loglevel value"), argv[0], level) << std::endl;
+						::std::exit(EXIT_FAILURE);
+					}
 				}
 				break;
 			case 'I':
@@ -410,7 +417,7 @@ void controller::run(int argc, char * argv[]) {
 	try {
 		rsscache = new cache(cache_file,&cfg);
 	} catch (const dbexception& e) {
-		std::cout << utils::strprintf(_("Error: opening the cache file `%s' failed: %s"), cache_file.c_str(), e.what()) << std::endl;
+		std::cerr << utils::strprintf(_("Error: opening the cache file `%s' failed: %s"), cache_file.c_str(), e.what()) << std::endl;
 		utils::remove_fs_lock(lock_file);
 		::exit(EXIT_FAILURE);
 	}
@@ -706,7 +713,7 @@ void controller::mark_all_read(unsigned int pos) {
 	}
 }
 
-void controller::reload(unsigned int pos, unsigned int max, bool unattended) {
+void controller::reload(unsigned int pos, unsigned int max, bool unattended, curl_handle *easyhandle) {
 	LOG(LOG_DEBUG, "controller::reload: pos = %u max = %u", pos, max);
 	if (pos < feeds.size()) {
 		std::tr1::shared_ptr<rss_feed> oldfeed = feeds[pos];
@@ -717,6 +724,7 @@ void controller::reload(unsigned int pos, unsigned int max, bool unattended) {
 		bool ignore_dl = (cfg.get_configvalue("ignore-mode") == "download");
 
 		rss_parser parser(oldfeed->rssurl(), rsscache, &cfg, ignore_dl ? &ign : NULL, api);
+		parser.set_easyhandle(easyhandle);
 		LOG(LOG_DEBUG, "controller::reload: created parser");
 		try {
 			oldfeed->set_status(DURING_DOWNLOAD);
@@ -789,10 +797,48 @@ void controller::reload_indexes(const std::vector<int>& indexes, bool unattended
 		v->set_status("");
 }
 
+struct feed_cmp {
+	const std::vector<std::tr1::shared_ptr<rss_feed> > &feeds;
+	feed_cmp(const std::vector<std::tr1::shared_ptr<rss_feed> > &f)
+		: feeds(f)
+	{
+	}
+	void extract(std::string &s, const std::string &url) const
+	{
+		size_t p = url.find("//");
+		p = (p == std::string::npos) ? 0 : p+2;
+		std::string suff(url.substr(p));
+		p = suff.find('/');
+		s = suff.substr(0, p);
+	}
+	bool operator()(unsigned a, unsigned b) const
+	{
+		std::tr1::shared_ptr<rss_feed> x = feeds[a];
+		std::tr1::shared_ptr<rss_feed> y = feeds[b];
+		const std::string &u = x->rssurl();
+		const std::string &v = y->rssurl();
+		
+		std::string domain1, domain2;
+		extract(domain1, u);
+		extract(domain2, v);
+		std::reverse(domain1.begin(), domain1.end());
+		std::reverse(domain2.begin(), domain2.end());
+		return domain1 < domain2;
+	}
+};
+
 void controller::reload_range(unsigned int start, unsigned int end, unsigned int size, bool unattended) {
-	for (unsigned int i=start;i<=end;i++) {
-		LOG(LOG_DEBUG, "controller::reload_range: reloading feed #%u", i);
-		this->reload(i, size, unattended);
+
+	std::vector<unsigned> v;
+	for (unsigned i=start;i<=end;++i)
+		v.push_back(i);
+	std::sort(v.begin(), v.end(), feed_cmp(feeds));
+
+	curl_handle easyhandle;
+
+	for (std::vector<unsigned>::iterator i = v.begin(); i!= v.end(); ++i) {
+		LOG(LOG_DEBUG, "controller::reload_range: reloading feed #%u", *i);
+		this->reload(*i, size, unattended, &easyhandle);
 	}
 }
 
@@ -841,6 +887,13 @@ void controller::reload_all(bool unattended) {
 		}
 	}
 
+	// refresh query feeds (update and sort)
+	LOG(LOG_DEBUG, "controller::reload_all: refresh query feeds");
+	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
+		v->prepare_query_feed(*it);
+	}
+	v->force_redraw();
+
 	sort_feeds();
 	update_feedlist();
 
@@ -1274,6 +1327,9 @@ void controller::execute_commands(char ** argv, unsigned int i) {
 			reload_all(true);
 		} else if (cmd == "print-unread") {
 			std::cout << utils::strprintf(_("%u unread articles"), rsscache->get_unread_count()) << std::endl;
+		} else {
+			std::cerr << utils::strprintf(_("%s: %s: unknown command"), argv[0], argv[i]) << std::endl;
+			::std::exit(EXIT_FAILURE);
 		}
 	}
 }
