@@ -84,10 +84,14 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 					if (itempos < visible_items.size()) {
 						visible_items[itempos].first->set_unread(false);
 						v->get_ctrl()->mark_article_read(visible_items[itempos].first->guid(), true);
-						if (itempos < visible_items.size()-1) {
-							f->set("itempos", utils::strprintf("%u", itempos + 1));
-						}
 						v->open_in_browser(visible_items[itempos].first->link());
+						if (!v->get_cfg()->get_configvalue_as_bool("openbrowser-and-mark-jumps-to-next-unread")) {
+							if (itempos < visible_items.size()-1) {
+								f->set("itempos", utils::strprintf("%u", itempos + 1));
+							}
+						} else {
+							process_operation(OP_NEXTUNREAD);
+						}
 						do_redraw = true;
 					}
 				} else {
@@ -130,8 +134,12 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 					} catch (const dbexception& e) {
 						v->set_status(utils::strprintf(_("Error while toggling read flag: %s"), e.what()));
 					}
-					if (itempos < visible_items.size()-1)
-						f->set("itempos", utils::strprintf("%u", itempos + 1));
+					if (!v->get_cfg()->get_configvalue_as_bool("toogleitemread-jumps-to-next-unread")) {
+						if (itempos < visible_items.size()-1)
+							f->set("itempos", utils::strprintf("%u", itempos + 1));
+					} else {
+						process_operation(OP_NEXTUNREAD);
+					}
 					do_redraw = true;
 				}
 			}
@@ -319,6 +327,8 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 					}
 					v->get_ctrl()->catchup_all(feed);
 				}
+				if (v->get_cfg()->get_configvalue_as_bool("markfeedread-jumps-to-next-unread"))
+					process_operation(OP_NEXTUNREAD);
 				do_redraw = true;
 				v->set_status("");
 			} catch (const dbexception& e) {
