@@ -11,6 +11,7 @@
 #include <libgen.h>
 #include <sys/utsname.h>
 
+#include <unistd.h>
 #include <sstream>
 #include <locale>
 #include <cwchar>
@@ -346,7 +347,7 @@ static size_t my_write_data(void *buffer, size_t size, size_t nmemb, void *userp
 	return size * nmemb;
 }
 
-std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcont, const char * authinfo) {
+std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcont, const char * authinfo, const std::string* postdata) {
 	std::string buf;
 
 	CURL * easyhandle = curl_easy_init();
@@ -355,6 +356,11 @@ std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcon
 	curl_easy_setopt(easyhandle, CURLOPT_WRITEFUNCTION, my_write_data);
 	curl_easy_setopt(easyhandle, CURLOPT_WRITEDATA, &buf);
 
+	if(postdata != NULL) {
+		curl_easy_setopt(easyhandle, CURLOPT_POST, 1);
+		curl_easy_setopt(easyhandle, CURLOPT_POSTFIELDS, postdata->c_str());
+	}
+
 	if (authinfo) {
 		curl_easy_setopt(easyhandle, CURLOPT_HTTPAUTH, get_auth_method(cfgcont->get_configvalue("http-auth-method")));
 		curl_easy_setopt(easyhandle, CURLOPT_USERPWD, authinfo);
@@ -363,7 +369,12 @@ std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcon
 	curl_easy_perform(easyhandle);
 	curl_easy_cleanup(easyhandle);
 
-	LOG(LOG_DEBUG, "utils::retrieve_url(%s): %s", url.c_str(), buf.c_str());
+	if(postdata != NULL) {
+		LOG(LOG_DEBUG, "utils::retrieve_url(%s)[%s]: %s", url.c_str(), postdata->c_str(), buf.c_str());
+	}
+	else {
+		LOG(LOG_DEBUG, "utils::retrieve_url(%s)[-]: %s", url.c_str(), buf.c_str());
+	}
 
 	return buf;
 }
@@ -495,6 +506,12 @@ std::string utils::to_s(unsigned int u) {
 	return buf;
 }
 
+std::string utils::signed_to_s(int u) {
+	char buf[32];
+	snprintf(buf, sizeof(buf), "%d", u);
+	return buf;
+}
+
 std::string utils::absolute_url(const std::string& url, const std::string& link) {
 	xmlChar * newurl = xmlBuildURI((const xmlChar *)link.c_str(), (const xmlChar *)url.c_str());
 	std::string retval;
@@ -539,7 +556,15 @@ std::string utils::get_useragent(configcontainer * cfgcont) {
 	if (ua_pref.length() == 0) {
 		struct utsname buf;
 		uname(&buf);
-		return utils::strprintf("%s/%s (%s %s; %s; %s) %s", PROGRAM_NAME, PROGRAM_VERSION, buf.sysname, buf.release, buf.machine, PROGRAM_URL, curl_version());
+		if (strcmp(buf.sysname, "Darwin") == 0) {
+			/* Assume it is a Mac from the last decade or at least Mac-like */
+			const char* PROCESSOR = "";
+			if (strcmp(buf.machine, "x86_64") == 0 || strcmp(buf.machine, "i386") == 0) {
+				PROCESSOR = "Intel ";
+			}
+			return utils::strprintf("%s/%s (Macintosh; %sMac OS X)", PROGRAM_NAME, PROGRAM_VERSION, PROCESSOR);
+		}
+		return utils::strprintf("%s/%s (%s %s)", PROGRAM_NAME, PROGRAM_VERSION, buf.sysname, buf.machine);
 	}
 	return ua_pref;
 }
@@ -738,9 +763,8 @@ std::string utils::quote(const std::string& str) {
 unsigned int utils::get_random_value(unsigned int max) {
 	static bool initialized = false;
 	if (!initialized) {
-		unsigned int var;
 		initialized = true;
-		srand(~(time(NULL) ^ getpid() ^ getppid() ^ var));
+		srand(~(time(NULL) ^ getpid() ^ getppid()));
 	}
 	return static_cast<unsigned int>(rand() % max);
 }
@@ -834,7 +858,7 @@ std::string utils::get_prop(xmlNode * node, const char * prop, const char * ns)
 	return retval;
 }
 
-int utils::get_auth_method(const std::string& type) {
+unsigned long utils::get_auth_method(const std::string& type) {
 	if (type == "any")
 		return CURLAUTH_ANY;
 	if (type == "basic")
